gchecky.model.new_order_notification_t

Package gchecky :: Module model :: Class new_order_notification_t |
[hide private]
[frames] | no frames]

# Class new_order_notification_t

source code

         object --+
                  |
          gxml.Node --+
                      |
          gxml.Document --+
                          |
    abstract_notification_t --+
                              |
                             new_order_notification_t

Nested Classes | [hide private]
Inherited from `gxml.Document`: `__metaclass__`

Instance Methods | [hide private]
Inherited from `gxml.Document`: `__str__`, `toxml` Inherited from `gxml.Node`: `__eq__`, `__init__`, `read`, `write` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Methods | [hide private]
Inherited from `gxml.Document`: `fromxml` Inherited from `gxml.Node`: `fields`, `set_fields`

Static Methods | [hide private]
Inherited from `gxml.Node`: `__new__`

Class Variables | [hide private]
| tag_name = ``'``new-order-notification``'`` The document's unique xml tag name.
| buyer_billing_address = `Node:PATH(buyer-billing-address):REQ:{`...``
| buyer_id = `Long:PATH(buyer-id):REQ`
| buyer_marketing_preferences = `Node:PATH(buyer-marketing-prefer`...``
| buyer_shipping_address = `Node:PATH(buyer-shipping-address):REQ`...``
| financial_order_state = `String:PATH(financial-order-state):REQ`...``
| fulfillment_order_state = `String:PATH(fulfillment-order-state)`...``
| order_adjustment = `Node:PATH(order-adjustment):REQ:{ order_adj`...``
| order_total = `Node:PATH(order-total):REQ:{ price_t }`
| shopping_cart = `Node:PATH(shopping-cart):REQ:{ shopping_cart_t }`
| _fields = ``{``'``buyer_billing_address``'``:` Node:PATH(buyer-billing-ad`...`` list of meta-Fields of this class.
Inherited from `abstract_notification_t`: `google_order_number`, `serial_number`, `timestamp`

Properties | [hide private]
Inherited from `object`: `__class__`

Class Variable Details | [hide private]

  ### buyer_billing_address Value:
      Node:PATH(buyer-billing-address):REQ:{ buyer_billing_address_t }

  ### buyer_marketing_preferences Value:
      Node:PATH(buyer-marketing-preferences):REQ:{ buyer_marketing_preferenc
      es_t }

  ### buyer_shipping_address Value:
      Node:PATH(buyer-shipping-address):REQ:{ buyer_shipping_address_t }

  ### financial_order_state Value:
      String:PATH(financial-order-state):REQ:VALS("REVIEWING","CHARGEABLE","
      CHARGING","CHARGED","PAYMENT_DECLINED","CANCELLED","CANCELLED_BY_GOOGL
      E")

  ### fulfillment_order_state Value:
      String:PATH(fulfillment-order-state):REQ:VALS("NEW","PROCESSING","DELI
      VERED","WILL_NOT_DELIVER")

  ### order_adjustment Value:
      Node:PATH(order-adjustment):REQ:{ order_adjustment_t }

  ### _fields list of meta-Fields of this class. Value:
      {'buyer_billing_address': Node:PATH(buyer-billing-address):REQ:{ buyer
      _billing_address_t },
       'buyer_id': Long:PATH(buyer-id):REQ,
       'buyer_marketing_preferences': Node:PATH(buyer-marketing-preferences)
      :REQ:{ buyer_marketing_preferences_t },
       'buyer_shipping_address': Node:PATH(buyer-shipping-address):REQ:{ buy
      er_shipping_address_t },
       'financial_order_state': String:PATH(financial-order-state):REQ:VALS(
      ...